==> qcad-3.15.5.3.tgz: lib/qcad/scripts/File/SaveAs/ts/SaveAs_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>SaveAs</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>File Dialog</source>
        <translation>Файловый диалог</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Use system file dialog</source>
        <translation>Использовать системный файловый диалог</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Saving</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Default format:</source>
        <translation>Формат по умолчанию:</translation>
    </message>
    <message>
        <location line="+37"/>
        <source>Show warning when saving to a file format that does not support 24bit colors</source>
        <translation>Показать предупреждение при сохранении в формате, который не поддерживает 24-битные цвета</translation>
    </message>
    <message>
        <location filename="../SaveAs.js" line="+38"/>
        <source>Load/Save</source>
        <translation>Загрузить/Сохранить</translation>
    </message>
    <message>
        <source>Save as</source>
        <translation type="vanished">Сохранить как</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>No export filters have been found. Aborting...</source>
        <translation>Фильтры для экспорта не найдены. Операция прервана...</translation>
    </message>
    <message>
        <location line="+65"/>
        <source>Format:</source>
        <translation>Формат:</translation>
    </message>
    <message>
        <location filename="../SaveAsInit.js" line="+2"/>
        <source>Save &amp;As...</source>
        <translation>Сохранить &amp;как...</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/File/SaveAs/ts/SaveAs_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>SaveAs</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>File Dialog</source>
        <translation>Файловый диалог</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Use system file dialog</source>
        <translation>Использовать системный файловый диалог</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Saving</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Default format:</source>
        <translation>Формат по умолчанию:</translation>
    </message>
    <message>
        <location line="+37"/>
        <source>Show warning when saving to a file format that does not support 24bit colors</source>
        <translation>Показать предупреждение при сохранении в формате, который не поддерживает 24-битные цвета</translation>
    </message>
    <message>
        <source>Load/Save</source>
        <translation type="vanished">Загрузить/Сохранить</translation>
    </message>
    <message>
        <source>Save as</source>
        <translation type="vanished">Сохранить как</translation>
    </message>
    <message>
        <location filename="../SaveAs.js" line="+38"/>
        <source>File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Open/Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+25"/>
        <source>No export filters have been found. Aborting...</source>
        <translation>Фильтры для экспорта не найдены. Операция прервана...</translation>
    </message>
    <message>
        <location line="+74"/>
        <source>Format:</source>
        <translation>Формат:</translation>
    </message>
    <message>
        <location filename="../SaveAsInit.js" line="+2"/>
        <source>Save &amp;As...</source>
        <translation>Сохранить &amp;как...</translation>
    </message>
</context>
</TS>
